<?php

namespace Restaurant\Googleapi\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Restaurant\Googleapi\Interfaces\CampaignRepositoryInterface;

class CampaignPublicController extends BaseController
{
    // use CampaignWorkflow;

    /**
     * Constructor.
     *
     * @param type \Restaurant\Campaign\Interfaces\CampaignRepositoryInterface $campaign
     *
     * @return type
     */
    public function __construct(CampaignRepositoryInterface $campaign)
    {
        $this->repository = $campaign;
        parent::__construct();
    }

    /**
     * Show campaign's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $campaigns = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('googleapi::campaign.names'))
            ->view('googleapi::public.campaign.index')
            ->data(compact('campaigns'))
            ->output();
    }


    /**
     * Show campaign.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $campaign = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($campaign->name . trans('googleapi::campaign.name'))
            ->view('googleapi::public.campaign.show')
            ->data(compact('campaign'))
            ->output();
    }

}
