<?php

namespace Restaurant\Googleapi\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\Googleapi\Models\Campaign;

class CampaignPolicy
{

    /**
     * Determine if the given user can view the campaign.
     *
     * @param UserPolicy $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function view(UserPolicy $user, Campaign $campaign)
    {
        if ($user->canDo('googleapi.campaign.view') && $user->isAdmin()) {
            return true;
        }

        return $campaign->user_id == user_id() && $campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign.
     *
     * @param UserPolicy $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('googleapi.campaign.create');
    }

    /**
     * Determine if the given user can update the given campaign.
     *
     * @param UserPolicy $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function update(UserPolicy $user, Campaign $campaign)
    {
        if ($user->canDo('googleapi.campaign.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign->user_id == user_id() && $campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign.
     *
     * @param UserPolicy $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Campaign $campaign)
    {
        return $campaign->user_id == user_id() && $campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign.
     *
     * @param UserPolicy $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Campaign $campaign)
    {
        if ($user->canDo('googleapi.campaign.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign.
     *
     * @param UserPolicy $user
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Campaign $campaign)
    {
        if ($user->canDo('googleapi.campaign.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
