<?php

namespace Restaurant\Googleapi\Providers;

use Illuminate\Support\ServiceProvider;

class GoogleapiServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'googleapi');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'googleapi');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerGoogleapi();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerGoogleapi()
    {
        $this->app->bind('googleapi', function($app) {
            return new Googleapi($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Googleapi', 'Lavalite\Googleapi\Facades\Googleapi');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('restaurant.googleapi', function ($app) {
            return $this->app->make('Restaurant\Googleapi\Googleapi');
        });

                // Bind Campaign to repository
        $this->app->bind(
            'Restaurant\Googleapi\Interfaces\CampaignRepositoryInterface',
            \Restaurant\Googleapi\Repositories\Eloquent\CampaignRepository::class
        );

        $this->app->register(\Restaurant\Googleapi\Providers\AuthServiceProvider::class);
                $this->app->register(\Restaurant\Googleapi\Providers\EventServiceProvider::class);
        
        $this->app->register(\Restaurant\Googleapi\Providers\RouteServiceProvider::class);
                // $this->app->register(\Restaurant\Googleapi\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and googleapi's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'restaurant.googleapi'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeGoogleapi::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['restaurant.googleapi'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('restaurant/googleapi.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/googleapi')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/googleapi')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
