<?php

namespace Restaurant\Googleapi\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Restaurant\Googleapi\Models\Campaign;

class CampaignAction
{
    /**
     * Perform the complete action.
     *
     * @param Campaign $campaign
     *
     * @return Campaign
     */
    public function complete(Campaign $campaign)
    {
        try {
            $campaign->status = 'complete';
            return $campaign->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Campaign $campaign
     *
     * @return Campaign
     */public function verify(Campaign $campaign)
    {
        try {
            $campaign->status = 'verify';
            return $campaign->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Campaign $campaign
     *
     * @return Campaign
     */public function approve(Campaign $campaign)
    {
        try {
            $campaign->status = 'approve';
            return $campaign->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Campaign $campaign
     *
     * @return Campaign
     */public function publish(Campaign $campaign)
    {
        try {
            $campaign->status = 'publish';
            return $campaign->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Campaign $campaign
     *
     * @return Campaign
     */
    public function archive(Campaign $campaign)
    {
        try {
            $campaign->status = 'archive';
            return $campaign->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Campaign $campaign
     *
     * @return Campaign
     */
    public function unpublish(Campaign $campaign)
    {
        try {
            $campaign->status = 'unpublish';
            return $campaign->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
