<?php

namespace Restaurant\Googleapi\Workflow;

use Restaurant\Googleapi\Models\Campaign;
use Validator;

class CampaignValidator
{

    /**
     * Determine if the given campaign is valid for complete status.
     *
     * @param Campaign $campaign
     *
     * @return bool / Validator
     */
    public function complete(Campaign $campaign)
    {
        return Validator::make($campaign->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given campaign is valid for verify status.
     *
     * @param Campaign $campaign
     *
     * @return bool / Validator
     */
    public function verify(Campaign $campaign)
    {
        return Validator::make($campaign->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given campaign is valid for approve status.
     *
     * @param Campaign $campaign
     *
     * @return bool / Validator
     */
    public function approve(Campaign $campaign)
    {
        return Validator::make($campaign->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given campaign is valid for publish status.
     *
     * @param Campaign $campaign
     *
     * @return bool / Validator
     */
    public function publish(Campaign $campaign)
    {
        return Validator::make($campaign->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given campaign is valid for archive status.
     *
     * @param Campaign $campaign
     *
     * @return bool / Validator
     */
    public function archive(Campaign $campaign)
    {
        return Validator::make($campaign->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given campaign is valid for unpublish status.
     *
     * @param Campaign $campaign
     *
     * @return bool / Validator
     */
    public function unpublish(Campaign $campaign)
    {
        return Validator::make($campaign->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
